@@ -1,7 +1,17 @@
+from __future__ import (
+    absolute_import,
+    print_function,
+    unicode_literals,
+)
+
+
 class SimpleType(object):
     def __init__(self, value):
         self.value = value
 
+    def __bool__(self):
+        return self.__nonzero__()
+
 
 class OnOff(SimpleType):
     '''
